@@ -1,3 +1,3 @@
-require 'capistrano/framework'
+require "capistrano/framework"
 
 load File.expand_path("../tasks/deploy.rake", __FILE__)
