@@ -1,8 +1,7 @@
-require 'spec_helper'
+require "spec_helper"
 
 module Capistrano
-
   describe Application do
-    let(:app) { Application.new  }
+    let(:app) { Application.new }
   end
 end
