@@ -185,12 +185,17 @@ module TestApp
     FileUtils.mv(config_path, location)
   end
 
-  def git_wrapper_path
-    "/tmp/git-ssh-my_app_name-#{stage}-#{current_user}.sh"
+  def git_wrapper_path_glob
+    "/tmp/git-ssh-*.sh"
   end
 
   def with_clean_bundler_env(&block)
     return yield unless defined?(Bundler)
-    Bundler.with_clean_env(&block)
+
+    if Bundler.respond_to?(:with_unbundled_env)
+      Bundler.with_unbundled_env(&block)
+    else
+      Bundler.with_clean_env(&block)
+    end
   end
 end
